local mod = ...

--[[

	Adds dung produced by animals, a dung heap for collection and impacts to production.

]]--


-- Job -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "DUNGCOLLECTOR_JOB",
	JobName = "DUNGCOLLECTOR_JOB_NAME",
	JobDescription = "DUNGCOLLECTOR_JOB_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 5.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		RightHandObject = {
			DataType = "HAND_OBJECT",
			Model = "PREFAB_TOOL_COAL_BURNER_SHOVEL"
		},
		WalkAnimation = "WALKING",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "DUNGCOLLECTOR_JOB"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "DUNGCOLLECTOR_JOB"
    }
})



-- Resource -------------------------------------------------------------------------------------

mod:registerAssetId("icons/Dung.png", "ICON_DUNG")

mod:register({
	DataType = "RESOURCE",
	Id = "DUNG_RESOURCE",
	ResourceName = "DUNG_RESOURCE_NAME",
	Icon = "ICON_DUNG",
	ResourceTypeList = { "RESOURCE" },
	IsTradable = false, -- available to store in the warehouse
	ResourceLayoutType = "CRATES",
	-- VillagerBuyingPrice = { Resource = "GOLD", Quantity = 2 },
	DisplayInInventory = true
})

mod:registerAssetId("icons/Compost.png", "ICON_COMPOST")

mod:register({
	DataType = "RESOURCE",
	Id = "COMPOST_RESOURCE",
	ResourceName = "COMPOST_RESOURCE_NAME",
	Icon = "ICON_COMPOST",
	ResourceTypeList = { "RESOURCE" },
	IsTradable = false, -- available to store in the warehouse
	ResourceLayoutType = "CRATES",
	-- VillagerBuyingPrice = { Resource = "GOLD", Quantity = 2 },
	DisplayInInventory = false
})



-- Assets
mod:registerAssetId("models/DungHeap.fbx/Prefab/DungHeapPart", "PREFAB_DUNGHEAP")
mod:registerAssetId("models/DungHeap.fbx/Prefab/CompostPart", "PREFAB_COMPOST")



-- Building Part Type
mod:registerEnumValue ("BUILDING_PART_TYPE", "PICKUP_PART_TYPE")



-- Building Asset Processor
mod:registerAssetProcessor("models/DungHeap.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Grounding
mod:registerPrefabComponent("models/DungHeap.fbx/Prefab/DungHeapPart", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/DungHeap.fbx/Prefab/CompostPart/Basket.001", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/DungHeap.fbx/Prefab/CompostPart/Basket.002", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/DungHeap.fbx/Prefab/CompostPart/Basket.003", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/DungHeap.fbx/Prefab/CompostPart/Basket.004", {DataType = "COMP_GROUNDED"})



-- -- Unlock dung heap on creation of poultry yard

-- mod:register({
-- 	DataType = "UNLOCKABLE_BUILDING_PART_LIST",
-- 	Id = "CHICKENYARD_UNLOCKABLE_BUILDING_PART_LIST",
-- 	AssetBuilding = "DUNGHEAP",
-- 	BuildingPartSetList = {
-- 		"DUNGHEAP_PART",
-- 		"COMPOST_PART"
-- 	}
-- })

-- mod:register({
-- 	DataType = "BUILDING_PROGRESS",
-- 	UnlockName = "CHICKENYARD_UNLOCK",
-- 	AssetBuildingList = {
-- 		"DUNGHEAP"
-- 	},
-- 	AssetUnlockableBuildingPartList = {
-- 		"CHICKENYARD_UNLOCKABLE_BUILDING_PART_LIST"
-- 	}
-- })

-- mod:register({
--     DataType = "BUILDING_PROGRESS_LIST",
--     Id = "CHICKENYARD_BUILDING_PROGRESS_LIST",
--     ProgressList = {
-- 		"CHICKENYARD_UNLOCK"
-- 	}
-- })



-- Building Function: Dung heap  -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "DUNGHEAP_FUNCTION",
    Name = "DUNGHEAP_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "DUNGCOLLECTOR_JOB", 
        Behavior = "BEHAVIOR_WORK"
	},
    InputInventoryCapacity = {{ Resource = "DUNG_RESOURCE", Quantity = 50 }},
    ResourceListNeeded = {{ Resource = "DUNG_RESOURCE", Quantity = 50 }},
    ResourceProduced = {{ Resource = "COMPOST_RESOURCE", Quantity = 0 }}
})



-- Building Function: Compost pile  -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_RESOURCE_GENERATOR",
    Id = "COMPOST_FUNCTION",
	Name = "COMPOST_FUNCTION_NAME",
	ResourceGenerated = "COMPOST_RESOURCE",
	IsForConsumer = false,
	IsInfinite = true
})



-- Building: Dung Heap -------------------------------------------------------------------------------------

mod:register({
	DataType = "BUILDING", 
	Id = "DUNGHEAP",
	Name = "DUNGHEAP_NAME",
	Description = "DUNGHEAP_DESC",
	BuildingType = "GENERAL",
	AssetCoreBuildingPart = "DUNGHEAP_PART",
	BuildingPartSetList = {
		{
			Name = "DUNGHEAP_SET1_NAME",
			BuildingPartList = { 
				"DUNGHEAP_PART"
			}
		},
		{
			Name = "DUNGHEAP_SET2_NAME",
			BuildingPartList = { 
				"COMPOST_PART"
			}
		}
	},
	IsEditable = true,
	RequiredPartList = {
		{ Category = "CORE", Min = 1, Max = 1 },
		{ Category = "PICKUP_PART_TYPE", Min = 1, Max = 1 }
	}
})



-- Building Part: Dung heap -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "DUNGHEAP_PART",
	Name = "DUNGHEAP_PART_NAME", 
	Description = "DUNGHEAP_PART_DESC", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_DUNGHEAP"
	},
	ConstructionVisual = "PREFAB_DUNGHEAP",
	Category = "CORE",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createCircle( 1.85, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } 
			}
		}
	},
	AssetBuildingFunction = "DUNGHEAP_FUNCTION",
	DesirabilityModifiers = { {
		Desirability = "DESIRABILITY_RESIDENTIAL",
		Type = "SUBSTRACT",
		Radius = 15.0,
		Value = 1.0
	} }
})



-- Building Part: Comopst baskets -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "COMPOST_PART",
	Name = "COMPOST_PART_NAME", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_COMPOST"
	},
	ConstructionVisual = "PREFAB_COMPOST",
	Category = "PICKUP_PART_TYPE",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createCircle( 1.00, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "COMPOST_FUNCTION"
})



-- -- Remove excess dung through a recurring event
-- mod:register({
-- 	DataType = "EVENT",
-- 	Id = "JACKIE_DUNG_EVENT",
-- 	Title = "JACKIE_DUNG_EVENT_TITLE",
-- 	Description = "JACKIE_DUNG_EVENT_DESC",
-- 	PanelVisual = "ILLUSTRATION_ESTATE_LABOR",
-- 	DaysToFirst = 1,
--     DaysBetweenOccurences = 7, 
-- 	IsRecurrent = true, 

-- 	ConditionList = {
-- 		{
-- 		DataType = "EVENT_CONDITION_BUILDING_BUILT",
-- 		AssetBuilding = "DUNGHEAP"
-- 		}
-- 	},
-- 	ActionList = {
-- 		{
-- 			DataType = "EVENT_ACTION_PAY",				
-- 			AmountToPay = {
-- 				{Resource = "DUNG_RESOURCE", Quantity = 10000},
-- 				{Resource = "COMPOST_RESOURCE", Quantity = 10000}
-- 			}
-- 		}
-- 	}
-- })



